import numpy as np


def convert_to_DN_and_add_noise(altius_image, radiance_to_dn_factor):
    """
    Parameters
    ----------
    altius_image : np.ndarray
        The image in units of photons/s/cm2/nm/sr

    radiance_to_dn_factor : float
        The conversion factor from photons/s/cm2/nm/sr to DN.  From config.

    Returns
    -------
    altius_image_dn : np.ndarray
        Same size as :code:`altius_image`, but scaled down to DN with
        realistic added shot noise and digitization noise.
    """
    altius_image_dn = altius_image * radiance_to_dn_factor
    # add noise:
    altius_image_dn = np.random.poisson(altius_image_dn * 2,
                                        np.shape(altius_image_dn)) / 2  # shot noise, 2 electrons per DN
    altius_image_dn = np.random.normal(altius_image_dn, 0.3)  # digitization noise
    altius_image_dn = np.round(altius_image_dn)
    return altius_image_dn


def convert_DN_to_radiance(altius_image, dn_to_radiance_factor):
    return altius_image * dn_to_radiance_factor
