# import unittest
#
# import matplotlib.pyplot as plt
# import numpy as np
# from skimage.transform import rescale
#
# from altius_l1pp_inflight.scene.disk_geometry import center_solar_disk, SolarGeometry, D_1AU
# from altius_l1pp_inflight.scene.generation.solar.hmi_files import HmiSunspotScenario
# from altius_l1pp_inflight.scene.generation.solar.virtual_solar_detector import SolarImage
# from altius_l1pp_inflight.scene.limbdark_mu_pierceandslaughter1977 import LimbDarkening_PS1977
#
#
# def produce_hmi_cross_section_with_limb_model():
#     xw = 4096
#     yw = 4096
#
#     solar_geometry = SolarGeometry(xw, yw, yw / 2, xw / 2)
#
#     solar_image = SolarImage.from_netcdf(HmiSunspotScenario.NO_SUNSPOTS, 8, 8, 30)
#
#     image = solar_image.hmi_disk_radiance()
#     calc_radius, x_c, y_c = center_solar_disk(image)
#     solar_geometry.set_disk(calc_radius, x_c, y_c, D_1AU)
#     mu_calc = solar_geometry._mu()
#
#     limb_darkening = LimbDarkening_PS1977()
#     mu_profile = np.linspace(0, 1.0, 50)
#     ld_wl_profile = limb_darkening.limb_darkening(617.3, mu_profile)
#     ld_calc = np.interp(mu_calc, mu_profile, ld_wl_profile)
#     flattened_calc = image / ld_calc
#
#     x1 = int(x_c - calc_radius / 2)
#     x2 = int(x_c + calc_radius / 2)
#     y1 = int(y_c - calc_radius / 2)
#     y2 = int(y_c + calc_radius / 2)
#
#     plt.figure()
#     plt.imshow(image)
#     plt.colorbar()
#     plt.title('HMI Image')
#
#     plt.figure()
#     plt.imshow(ld_calc)
#     plt.title('Limb Darkening')
#     plt.colorbar()
#
#     plt.figure()
#     im_profile = image[int(y_c), :]
#     ld_p = ld_calc[int(y_c), :]
#     plt.plot(im_profile / np.nanmax(im_profile) + 0.06)
#     plt.plot(ld_p)
#
#     plt.figure()
#     plt.imshow(flattened_calc[y1:y2, x1:x2])
#     plt.colorbar()
#
#     plt.show()
#
#
# def produce_altius_cross_section_with_limb_model():
#     xw = 4096
#     yw = 4096
#
#     solar_geometry = SolarGeometry(xw, yw, yw / 2, xw / 2)
#
#     solar_image = SolarImage.from_netcdf(HmiSunspotScenario.NO_SUNSPOTS, 8, 8, 30)
#
#     image = solar_image.hmi_disk_radiance()
#     calc_radius, x_c, y_c = center_solar_disk(image)
#     solar_geometry.set_disk(calc_radius, x_c, y_c, D_1AU)
#     mu_calc = solar_geometry._mu()
#
#     limb_darkening = LimbDarkening_PS1977()
#     mu_profile = np.linspace(0, 1.0, 50)
#     ld_wl_profile = limb_darkening.limb_darkening(617.3, mu_profile)
#     ld_new_wl_profile = limb_darkening.limb_darkening(350, mu_profile)
#     ld_new = np.interp(mu_calc, mu_profile, ld_new_wl_profile)
#     ld_calc = np.interp(mu_calc, mu_profile, ld_wl_profile)
#     flattened_calc = image / ld_calc
#
#     new_hmi_wl = flattened_calc * ld_new
#
#     x1 = int(x_c - calc_radius / 2)
#     x2 = int(x_c + calc_radius / 2)
#     y1 = int(y_c - calc_radius / 2)
#     y2 = int(y_c + calc_radius / 2)
#
#     plt.figure()
#     plt.imshow(image)
#     plt.colorbar()
#     plt.title('HMI Image')
#
#     # plt.figure()
#     # plt.imshow(ld_calc)
#     # plt.title('Limb Darkening')
#     # plt.colorbar()
#
#     plt.figure()
#     im_profile = image[int(y_c), :]
#     ld_p = ld_calc[int(y_c), :]
#     plt.plot(im_profile / np.nanmax(im_profile) + 0.06)
#     plt.title('Cross-section of HMI Image')
#     plt.plot(ld_p)
#
#     plt.figure()
#     plt.imshow(flattened_calc)
#     plt.title('Flattened HMI Image')
#
#     plt.figure()
#     plt.imshow(flattened_calc[y1:y2, x1:x2])
#     plt.title('Flattened HMI Image Center Region')
#     plt.colorbar()
#
#     plt.figure()
#     plt.imshow(new_hmi_wl)
#     plt.title('Re-calculated HMI at 350 nm')
#     plt.colorbar()
#
#     # place the HMI image in a detector space assuming 1 solar radius = 0.26 deg and a 1 deg x 1 deg detector
#     deg_per_radius = 0.26
#     detector_width = int(4 * calc_radius)
#     detector_angle_width = detector_width / calc_radius * deg_per_radius
#
#     new_hmi_wl[np.isnan(new_hmi_wl)] = 0.0
#
#     detector_hi_res = np.zeros((detector_width, detector_width))
#     detector_hi_res[600:(600 + yw), 2500:(2500 + xw)] = new_hmi_wl
#
#     plt.figure()
#     plt.imshow(detector_hi_res)
#     plt.title('Hi res detector of width 1.03x1.03 deg')
#
#     altius_image = rescale(detector_hi_res, 750 / detector_width)
#
#     plt.figure()
#     plt.imshow(altius_image)
#     plt.title('ALTIUS resolution of detector image')
#
#     r, ch, cv = center_solar_disk(altius_image)
#
#     solar_geometry = SolarGeometry(len(altius_image[0]), len(altius_image), len(altius_image[0]) / 2,
#                                    len(altius_image) / 2)
#     solar_geometry.set_disk(r, ch, cv, D_1AU)
#     mu_calc = solar_geometry._mu()
#
#     limb_darkening = LimbDarkening_PS1977()
#     mu_profile = np.linspace(0, 1.0, 50)
#     ld_new_wl_profile = limb_darkening.limb_darkening(350, mu_profile)
#     ld_calc = np.interp(mu_calc, mu_profile, ld_new_wl_profile)
#     flattened_altius = altius_image / ld_calc
#
#     plt.figure()
#     plt.imshow(flattened_altius)
#     plt.title('Flattened ALTIUS Image')
#     plt.colorbar()
#
#     plt.figure()
#     plt.imshow(flattened_altius[int(cv - r / 2):int(cv + r / 2), int(ch - r / 2):int(ch + r / 2)])
#     plt.title('Flattened Inner Region ALTIUS')
#     plt.colorbar()
#
#     plt.figure()
#     plt.plot(flattened_altius[int(cv - r / 2), int(ch - r / 2):int(ch + r / 2)])
#     plt.plot(flattened_altius[int(cv), int(ch - r / 2):int(ch + r / 2)])
#     plt.title('Cross section of flattened ALTIUS at edge and middle of central region')
#
#     plt.show()
#
# class TestLimbCorrectionImages(unittest.TestCase):
#
#     def test_hmi_cross_section_limb_correction(self):
#         produce_hmi_cross_section_with_limb_model()
#
#     def test_altius_cross_section_limb_correction(self):
#         produce_altius_cross_section_with_limb_model()
#
#
# if __name__ == '__main__':
#     # produce_hmi_cross_section_with_limb_model()
#     produce_altius_cross_section_with_limb_model()
